@@ -29,13 +29,11 @@ class MailImporter::FilterTheBatPrivate
 {
 public:
     FilterTheBatPrivate()
-        : mImportDirDone(0)
-        , mTotalDir(0)
     {
     }
 
-    int mImportDirDone;
-    int mTotalDir;
+    int mImportDirDone = 0;
+    int mTotalDir = 0;
 };
 
 /** Default constructor. */
@@ -211,7 +209,6 @@ void FilterTheBat::importFiles(const QString &FileName)
                 offsets.append(endOfEmail);
             }
         }
-        // filterInfo()->addInfoLogEntry(i18n("--COUNTED: %1").arg(count));
 
         // IMPORT the messages:
         if (!offsets.empty() || (offsets.empty() && (tbb.size() > 3128))) {
